@@ -272,3 +272,11 @@ get_worker_queues = '''
     }
   }
 '''
+
+get_queueLocks = '''
+query($workerCode:String, $queueName:String){
+  queueLocks(orderBy:{desc:ID}, filter:{workerCode:$workerCode, queueName:$queueName , active:true}){
+    id
+    active
+  }
+}'''
\ No newline at end of file
